==> pylegifrance-0.0.3a4.tar.gz: pylegifrance-0.0.3a4/README.md <==
# PyLegifrance

<!-- Build and License -->
[![GitHub Actions][ci-shield]][ci-url]

## À propos

Librairie python qui simplifie l'interrogation des contenus de legifrance en créant des fonctions pythons prêtes à l'emploi pour la recherche ou la consultation de textes légaux et réglementaires.  
Elle repose sur l'utilisation de pydantic pour gérer les structures de données d'interrogation et de réponse de l'API legifrance. A terme l'intégralité des fonctions de l'API legifrance seront disponibles sous forme de fonctions python. 

Si vous souhaitez accéder directement à une API simplifiée, c'est par ici : [https://lab.dassignies.law/api/docs](https://lab.dassignies.law/api/docs) 

Pour un serveur MCP Legifrance, c'est par ici : [https://github.com/rdassignies/mcp-server-legifrance](https://github.com/rdassignies/mcp-server-legifrance)

## Documentation

La documentation complète est disponible ici : [https://pylegifrance.github.io/pylegifrance/](https://pylegifrance.github.io/pylegifrance/)

Elle inclut :
- [Tutoriels](https://pylegifrance.github.io/pylegifrance/tutorials/) - Apprentissage guidé pour les débutants
- [Guides pratiques](https://pylegifrance.github.io/pylegifrance/how-to/) - Instructions d'installation et d'utilisation
- [Référence API](https://pylegifrance.github.io/pylegifrance/reference/) - Documentation technique détaillée
- [Explications](https://pylegifrance.github.io/pylegifrance/explanation/) - Concepts et roadmap

## Fonctionnalités principales

- Recherche dans les codes français
- Recherche dans les lois, ordonnances, décrets et arrêtés

Pour des exemples d'utilisation, consultez la [documentation](https://pylegifrance.github.io/pylegifrance/how-to/).

## Contact

Raphael d'Assignies - [LinkedIn](https://www.linkedin.com/in/dassignies/)  
Site web: [https://dassignies.law](https://dassignies.law)

**Contributeurs :**  
Frederic Ferrera - [LinkedIn](https://www.linkedin.com/in/fferrera31/)  
Site web: https://fredferre.com

<!-- MARKDOWN LINKS & IMAGES -->
[ci-shield]: https://github.com/pylegifrance/pylegifrance/actions/workflows/test.yml/badge.svg?style=for-the-badge
[ci-url]: https://github.com/pylegifrance/pylegifrance/actions

==> pylegifrance-0.1.0b2.tar.gz: pylegifrance-0.1.0b2/README.md <==
# PyLegifrance

<!-- Build and License -->
[![GitHub Actions][ci-shield]][ci-url]

## À propos

Librairie python qui simplifie l'interrogation des contenus de legifrance en créant des fonctions pythons prêtes à l'emploi pour la recherche ou la consultation de textes légaux et réglementaires.  
Elle repose sur l'utilisation de pydantic pour gérer les structures de données d'interrogation et de réponse de l'API legifrance. A terme l'intégralité des fonctions de l'API legifrance seront disponibles sous forme de fonctions python. 

Si vous souhaitez accéder directement à une API simplifiée, c'est par ici : [https://lab.dassignies.law/api/docs](https://lab.dassignies.law/api/docs) 

Pour un serveur MCP Legifrance, c'est par ici : [https://github.com/rdassignies/mcp-server-legifrance](https://github.com/rdassignies/mcp-server-legifrance)

## Documentation

La documentation complète est disponible ici : [https://pylegifrance.github.io/pylegifrance/](https://pylegifrance.github.io/pylegifrance/)

Elle inclut :
- [Tutoriels](https://pylegifrance.github.io/pylegifrance/tutoriels/) - Apprentissage guidé pour les débutants
- [Guides pratiques](https://pylegifrance.github.io/pylegifrance/#installation) - Instructions d'installation et d'utilisation
- [Référence API](https://pylegifrance.github.io/pylegifrance/reference/) - Documentation technique détaillée
- [Explications](https://pylegifrance.github.io/pylegifrance/explanation/) - Concepts et roadmap

## Fonctionnalités principales

- Recherche dans les codes français
- Recherche dans les lois, ordonnances, décrets et arrêtés
- Recherche dans la jurisprudence judiciaire 

Pour des exemples d'utilisation, consultez la [documentation](https://pylegifrance.github.io/pylegifrance/guides-pratiques/)).

## Contact

Raphael d'Assignies - [LinkedIn](https://www.linkedin.com/in/dassignies/)  
Site web: [https://dassignies.law](https://dassignies.law)

**Contributeurs :**  
Frederic Ferrera - [LinkedIn](https://www.linkedin.com/in/fferrera31/)  
Site web: https://fredferre.com

<!-- MARKDOWN LINKS & IMAGES -->
[ci-shield]: https://github.com/pylegifrance/pylegifrance/actions/workflows/test.yml/badge.svg?style=for-the-badge
[ci-url]: https://github.com/pylegifrance/pylegifrance/actions
